Module error

Module error 

Holds the error type for matrixlab

Enums

Error
This is the general error type for our library. It can represent any failed operation on a matrix, including building a new matrix or a failed operation like matrix multiplication